@@ -1,5 +1,4 @@
-`panelcontour` <-
-function(x, y, ...)
+panelcontour <- function(x, y, ...)
 {
      usr <- par("usr"); on.exit(par(usr))
      par(usr = c(usr[1:2], 0, 1.5) )
@@ -9,4 +8,3 @@ function(x, y, ...)
      #contour(kd,add=TRUE,drawlabels=FALSE,nlevels=2,...)
      contour(kd,add=TRUE,drawlabels=FALSE,levels=c(kdmax*0.01,kdmax*0.5,kdmax*0.9),col=c("red","blue","green"),...)
 }
-
