@@ -2,7 +2,7 @@
 
 //void user_wait();
 //void anerror(char *error_text);
-double GetLik(double *X,double mean,double sd,int datasize,int isosize);
+double GetLik(double *X,double mean,double sd,int datasize);
 double maximum (double e, double f);
 double rtruncn (double a, double b);
 double truncatedwalk (double old, double sd, double low, double high);
